.. _changlog:

Changelog
=========

Version 0.1.0
--------------
*Released on: 24/04/2020*

* Added :py:class:`pyproximal.optimization.sr3.SR3` solver
* Added :py:class:`pyproximal.projection.AffineSetProj` and
  :py:class:`pyproximal.AffineSet` operators
* Fixed :py:class:`pyproximal.Huber` operator


Version 0.0.0
-------------
*Released on: 17/01/2021*

* First official release.
